.. _installing:

############
 Installing
############

To install the package, you can use the following command:

.. code:: bash

   pip install anemoi-inference

**************
 Contributing
**************

.. code:: bash

   git clone ...
   cd anemoi-inference
   pip install .[dev]
   pip install -r docs/requirements.txt

You may also have to install pandoc on MacOS:

.. code:: bash

   brew install pandoc
